@@ -1,6 +1,6 @@
 from requests import Session
 
-from manga_py.base_classes import WebDriver
+from manga_py.base_classes.web_driver import make_driver
 from manga_py.provider import Provider
 
 
@@ -11,10 +11,9 @@ class TsuminoCom:
         self.provider = provider
 
     def get_cookies(self, url):
-        web_driver = WebDriver()
-        driver = web_driver.get_driver()
+        driver = make_driver()
         driver.get(url)
-        iframe = driver.find_element_by_css_selector(".g-recaptcha iframe")
+        iframe = driver.find_element(".g-recaptcha iframe")
         src = self.provider.http_get(iframe.get_attribute('src'))
         driver.close()
 
